@@ -12,6 +12,7 @@ from graia.broadcast.utilles import printer
 from graia.application.message.chain import MessageChain, MessageIndex
 from graia.application.message.elements import Element
 from graia.application.message.elements.internal import (
+    At,
     App,
     Json,
     Plain,
@@ -39,8 +40,8 @@ class Literature(BaseDispatcher):
     prefixs: Tuple[str]  # 匹配前缀
     arguments: Dict[str, ParamPattern]
 
-    allow_quote: bool = False
-    skip_one_at_in_quote: bool = False
+    allow_quote: bool
+    skip_one_at_in_quote: bool
 
     def __init__(self, *prefixs, arguments: Dict[str, ParamPattern] = None, allow_quote: bool = False, skip_one_at_in_quote: bool = False) -> None:
         self.prefixs = prefixs
@@ -117,7 +118,7 @@ class Literature(BaseDispatcher):
                         Plain(i)
                         if not re.match("^\$\d+$", i)
                         else id_elem_map[int(i[1:])]
-                        for i in printer(re.split(r"((?<!\\)\$[0-9]+)", v))
+                        for i in re.split(r"((?<!\\)\$[0-9]+)", v)
                         if i
                     ]
                 ).asMerged()
@@ -190,8 +191,7 @@ class Literature(BaseDispatcher):
             raise ExecutionStop()
         if self.allow_quote and message_chain.has(Quote):
             # 自动忽略自 Quote 后第一个 At
-            # 0: Quote, 1: At, 2: Plain(一个空格, 可能会在以后的 mirai 版本后被其处理, 这里先自动处理这个了.)
-            message_chain = message_chain[(3, None):]
+            message_chain = message_chain[(1, None):]
             if self.skip_one_at_in_quote and message_chain.__root__:
                 if message_chain.__root__[0].__class__ is At:
                     message_chain = message_chain[(1, 1):]
