@@ -1,11 +1,13 @@
-from typing import Any, List
+from typing import Any, List, Optional
 from dataclasses import dataclass
 
 
 @dataclass(init=True, eq=True, repr=True)
 class ParamPattern:
-    keywords: List[str]
+    longs: List[str]
+    short: Optional[str] = None
     default: Any = None
+    help_message: Optional[str] = None
 
 
 @dataclass(init=True, eq=True, repr=True)
