@@ -18,7 +18,7 @@ class PatternReceiver(BaseModel):
     def __init__(self, name: str, isGreed: bool = False) -> None:
         super().__init__(name=name, isGreed=isGreed)
 
-    @validator("name")
+    @validator("name", allow_reuse=True)
     def name_checker(cls, v):
         if not regex.match("^[a-zA-Z_][a-zA-Z0-9_]*$", v):
             raise ValueError("invaild name")
